package generaldemo;

import com.bytescout.barcodereader.*;
import java.awt.image.BufferedImage;
import java.io.Console;
import java.io.File;
import java.io.IOException;
import java.util.EnumSet;
import javax.imageio.ImageIO;

public class GeneralDemo
{
	public static void main(String[] args) throws IOException
	{
		// Create Barcode Reader instance
		Reader reader = new Reader();
		reader.setRegistrationName("demo");
		reader.setRegistrationKey("demo");
		
		// Set barcode types to find:
		reader.setBarcodeTypesToFind(EnumSet.of(BarcodeType.Code39, BarcodeType.QRCode));
		
		// Demonstrate barcode decoding from image file:
		FoundBarcode[] foundBarcodes = reader.readFromFile("..\\SampleCode39.jpg");
		for (FoundBarcode barcode : foundBarcodes)
		{
			System.out.println("Found barcode in file SampleCode39.jpg:");
			System.out.println("Type = " + barcode.getType());
			System.out.println("Value = " + barcode.getValue());
			System.out.println("Confidence = " + barcode.getConfidence());
			System.out.println("Rectangle = " + barcode.getRectangle());
		}
		
		System.out.println();
		
		// Demonstrate barcode decoding from BufferedImage object
		BufferedImage image = ImageIO.read(new File("..\\SampleQRCode.jpg"));
		foundBarcodes = reader.readFromImage(image);
		for (FoundBarcode barcode : foundBarcodes)
		{
			System.out.println("Found barcode in file SampleQRCode.jpg:");
			System.out.println("Type = " + barcode.getType());
			System.out.println("Value = " + barcode.getValue());
			System.out.println("Confidence = " + barcode.getConfidence());
			System.out.println("Rectangle = " + barcode.getRectangle());
		}
		
		System.out.flush();
	}
}
